@@ -3,6 +3,8 @@ import argparse
 from elasticgit.commands.avro import SchemaDumper, SchemaLoader
 from elasticgit.commands.gitmodel import MigrateGitModelRepo
 from elasticgit.commands.shell import EGShell
+from elasticgit.commands.version import VersionTool
+from elasticgit.commands.resync import ResyncTool
 
 
 def add_command(subparsers, dispatcher_class):  # pragma: no cover
@@ -23,6 +25,8 @@ def get_parser():  # pragma: no cover
     add_command(subparsers, SchemaLoader)
     add_command(subparsers, MigrateGitModelRepo)
     add_command(subparsers, EGShell)
+    add_command(subparsers, VersionTool)
+    add_command(subparsers, ResyncTool)
 
     return parser
 
